import dayjs from 'dayjs';
import { isEqual } from 'lodash';
import React, { memo, useEffect, useMemo, useState } from 'react';
import styles from './index.less';

interface PropsType {
  value: { label: string; value: any };
  defaultValue?: { label: string; value: any };
  onChange: (value: any) => void;
  /** today 今日 | week 本周 | month 本月 | year 本年 | last_month 近一月 | custom 自定义 */
  dateRange: ['today'?, 'week'?, 'month'?, 'year'?, 'last_month'?];
  /** 自定义模式 */
  datePickerMode?: 'date' | 'month' | 'year' | 'dateRange';
  /** showCustom 是否显示自定义 */
  showCustom?: boolean;
}

/**
 *
 * 对照表
 * @description 在任意地方获取相同值时，可以从这里获取初始值
 * @exports
 *  */
export const DATE_MAPPING = {
  today: {
    label: '今日',
    get: () => ({
      start: dayjs().format('YYYY-MM-DD'),
      end: dayjs().format('YYYY-MM-DD'),
    }),
  },
  week: {
    label: '本周',
    get: () => ({
      start: dayjs().startOf('week').format('YYYY-MM-DD'),
      end: dayjs().endOf('week').format('YYYY-MM-DD'),
    }),
  },
  month: {
    label: '本月',
    get: () => ({
      start: dayjs().startOf('month').format('YYYY-MM-DD'),
      end: dayjs().endOf('month').format('YYYY-MM-DD'),
    }),
  },
  year: {
    label: '本年',
    get: () => ({
      start: dayjs().startOf('year').format('YYYY-MM-DD'),
      end: dayjs().endOf('year').format('YYYY-MM-DD'),
    }),
  },
  last_month: {
    label: '近一月',
    get: () => ({
      start: dayjs().subtract(1, 'month').format('YYYY-MM-DD'),
      end: dayjs().format('YYYY-MM-DD'),
    }),
  },
};

/** 基础选择器 */
const TimeSelect: React.FC<PropsType> = memo((props) => {
  const {
    value,
    defaultValue,
    dateRange = ['today', 'week', 'month', 'year', 'last_month'],
    datePickerMode,
    onChange,
  } = props;

  const [curVal, setCurVal] = useState(defaultValue);

  const options = useMemo(() => {
    return dateRange
      .map((item) => {
        if (item && item in DATE_MAPPING) {
          return {
            label: DATE_MAPPING[item].label,
            value: DATE_MAPPING[item].get(),
          };
        }
        return undefined;
      })
      .filter((item) => item !== undefined);
  }, [dateRange]);

  useEffect(() => {
    if (!isEqual(value, curVal)) {
      setCurVal(value);
    }
  }, [value]);

  const clickHandle = (item: any) => {
    setCurVal(item);
    onChange && onChange(item);
  };

  return (
    <div className={styles.container}>
      {options?.map((item) => {
        const isSelected = curVal?.label === item.label;
        return (
          <div key={item.label} onClick={() => clickHandle(item)}>
            {item.label}
          </div>
        );
      })}
    </div>
  );
});

export default TimeSelect;
