import React, { useState, useRef } from 'react';
import { Flex, Space, Badge } from 'antd';
import EChartsReact from 'echarts-for-react';
import * as echarts from 'echarts';
import styles from './index.less';
import { useBridgeManage } from '../../context';

type TabKey = 'level' | 'type';

const BridgeTypeDistribution: React.FC = () => {
  const { viewType, isUsingValue } = useBridgeManage();
  const [activeTab, setActiveTab] = useState<TabKey>('level');
  const chartRef = useRef<EChartsReact>(null);
  
  const data = {
    bridge: {
      level: [
        { value: 16, name: 'I等', percent: 36.25},
        { value: 16, name: 'II等', percent: 46.25},
        { value: 16, name: 'III等', percent: 56.25}
      ],
      type: [
        { value: 16, name: '特大桥', percent: 36.25},
        { value: 16, name: '大桥', percent: 46.25},
        { value: 16, name: '中桥', percent: 56.25}
      ],
    },
    road: {
      level: [
        { value: 16, name: 'I等', percent: 36.25},
        { value: 16, name: 'II等', percent: 46.25},
        { value: 16, name: 'III等', percent: 56.25},
        { value: 16, name: 'IV等', percent: 66.25},
        { value: 16, name: 'V等', percent: 76.25},
      ],
      type: [
        { value: 16, name: '主干道', percent: 36.25},
        { value: 16, name: '次干道', percent: 46.25},
        { value: 16, name: '支路', percent: 56.25},
        { value: 16, name: '一级公路', percent: 66.25},
        { value: 16, name: '二级公路', percent: 76.25},
      ]
    }
  };

//   const fixedData = {
//     bridge: [36.25, 46.25, 56.25],
//     road: [36.25, 46.25, 56.25, 66.25, 76.25]
//   };

  const tabLabels: Record<TabKey, string> = {
    level: '养护等级',
    type: '养护类别'
  };

  const tabs: TabKey[] = ['level', 'type'];

  const pieOption = {
    color: ['#FF9B5D', '#FFE335', '#35B2FF', '#77E67B', '#00FFB3'],
    series: [{
      type: 'pie',
      padAngle: 5,
      // radius: ['46%', '66%'],
      radius: ['65%', '88%'],
      // center: ['36%', '35%'],
      label: {
        show: false
      },
      data: data[viewType === 'road' ? 'road' : 'bridge'][activeTab],
    }]
  };

  const onChartReady = (instance: echarts.ECharts) => {
    instance.resize();
  };

  const title = viewType === 'road' ? '道路类型分布' : '桥梁类型分布';
  const unit = viewType === 'road' ? '条' : '座';

  return (
    <div className={styles.container}>
      <div className={styles.header}>
        <div className={styles.title}>{title}</div>
        <div className={styles.tabWrapper}>
          <Space size={10}>
            {tabs.map(tab => (
              <div
                key={tab}
                className={`${styles.tabBtn} ${activeTab === tab ? styles.active : ''}`}
                onClick={() => setActiveTab(tab)}
              >
                {tabLabels[tab]}
              </div>
            ))}
          </Space>
        </div>
      </div>

      <Flex className={styles.content}>
        <div className={styles.chart}>
          <EChartsReact 
            ref={chartRef}
            option={pieOption}
            style={{ height: 183, width: 183 }}
            onChartReady={onChartReady}
          />
        </div>
        
        <div className={`${styles.legend} ${viewType === 'road' ? styles.roadLegend : ''}`}>
        {/* <div className={styles.legend}> */}
          {pieOption.series[0].data.map((item, index) => (
            <Flex key={index} align="center" className={styles.legendItem}>
              <Badge color={pieOption.color[index]} />
              <span className={styles.name}>{item.name}</span>
              <span className={styles.value}>{isUsingValue ? item.value : '--'}</span>
              <span className={styles.unit}>{unit}</span>
              <span className={styles.percent}>{isUsingValue ? item.percent : '--'}%</span>
            </Flex>
          ))}
        </div>
      </Flex>
    </div>
  );
};

export default BridgeTypeDistribution; 