import React, { useEffect, useRef } from 'react';
import * as echarts from 'echarts';
import styles from './index.less';

interface StatisticsChartProps {
  searchTime: {
    startTime: string;
    endTime: string;
  };
}

const StatisticsChart: React.FC<StatisticsChartProps> = ({ searchTime }) => {
  const chartRef = useRef<HTMLDivElement>(null);
  let isUsingValue = false;
  const data = [
    { name: '工程渣土', value: 16.23, percentage: 56.25, color: '#FF9B5D' },
    { name: '工程泥浆', value: 16.23, percentage: 56.25, color: '#FFE335' },
    { name: '装修垃圾', value: 16.23, percentage: 56.25, color: '#35B2FF' },
    { name: '工程垃圾', value: 16.23, percentage: 56.25, color: '#77E67B' },
    { name: '拆除垃圾', value: 16.23, percentage: 56.25, color: '#00FFB3' }
  ];

  const showValue = (value: number | string) => {
    if(isUsingValue){
      return value;
    }
    return '--';
  }

  useEffect(() => {
    if (!chartRef.current) return;
    
    const chart = echarts.init(chartRef.current);
    
    const option = {
      tooltip: {
        trigger: 'item',
        backgroundColor: 'rgba(8, 24, 63, 0.9)',
        borderColor: '#13659680',
        borderWidth: 1,
        textStyle: {
          color: '#BCCEE9'
        }
      },
      title: {
        text: isUsingValue ? '5623.85' : '---.--',
        subtext: '共计（万方）',
        left: '65px',  // 根据需求调整位置
        top: '54px',   // 根据需求调整位置
        textStyle: {
          color: '#FFFFFF',
          fontSize: 24,
          fontFamily: 'D-DIN',
          lineHeight: 31
        },
        subtextStyle: {
          color: '#BCCEE9',
          fontSize: 16,
          lineHeight: 23
        }
      },
      series: [
        {
          type: 'pie',
          radius: ['50%', '70%'],
          center: ['40%', '35%'],  // 调整环形图位置
          data: data.map(item => ({
            name: item.name,
            value: item.value,
            itemStyle: {
              color: item.color
            }
          })),
          label: {
            show: false
          }
        }
      ]
    };

    chart.setOption(option);

    return () => {
      chart.dispose();
    };
  }, []);

  return (
    <div className={styles.container}>
      <div className={styles.title}>建筑垃圾申报排放统计</div>
      <div className={styles.content}>
        <div className={styles.chart}>
          <div ref={chartRef} style={{ width: '270px', height: '270px' }} />
        </div>
        <div className={styles.legend}>
          <div className={styles.legendColumn}>
            {data.slice(0, 3).map((item, index) => (
              <div key={index} className={styles.legendItem}>
                <div className={styles.dot} style={{ background: item.color }} />
                <div className={styles.info}>
                  <div className={styles.type}>{item.name}</div>
                  <div className={styles.value}>
                    {showValue(item.value)}
                    <span className={styles.unit}>万方</span>
                  </div>
                  <div className={styles.percentage}>{showValue(item.percentage)}%</div>
                </div>
              </div>
            ))}
          </div>
          <div className={styles.legendColumn}>
            {data.slice(3).map((item, index) => (
              <div key={index} className={styles.legendItem}>
                <div className={styles.dot} style={{ background: item.color }} />
                <div className={styles.info}>
                  <div className={styles.type}>{item.name}</div>
                  <div className={styles.value}>
                    {showValue(item.value)}
                    <span className={styles.unit}>万方</span>
                  </div>
                  <div className={styles.percentage}>{showValue(item.percentage)}%</div>
                </div>
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};

export default StatisticsChart; 